@@ -1,26 +1,48 @@
-import warnings
+"""Functions to calculate AMDs and PDDs.
+"""
+
+from typing import Union, Tuple
 import numpy as np
-from .core.nearest_neighbours import nearest_neighbours
-from .core.PeriodicSet import PeriodicSet
+from ._nearest_neighbours import nearest_neighbours
+from .periodicset import PeriodicSet
 from collections import defaultdict
 
-def AMD(periodic_set, k):
-    """
-    Computes an AMD vector up to k from a periodic set.
+def AMD(periodic_set: Union[PeriodicSet, Tuple[np.ndarray, np.ndarray]], k: int) -> np.ndarray:
+    """Computes an AMD vector up to `k` from a periodic set.
     
     Parameters
     ----------
-    periodic_set : amd.PeriodicSet or tuple of ndarrays (motif, cell)
-        Representation of the periodic set, in Cartesian coordinates.
-        amd.CifReader yields PeriodicSets which can be given here. 
-        Otherwise pass a tuple of arrays (motif, cell) in Cartesian form. 
+    periodic_set : :class:`.periodicset.PeriodicSet` or tuple of ndarrays
+        A periodic set represented by a :class:`.periodicset.PeriodicSet` object or 
+        by a tuple (motif, cell) with coordinates in Cartesian form.
     k : int
-        A :math:`m_b` by k PDD matrix (with weights in the first column).
+        Length of AMD returned.
         
     Returns
     -------
     ndarray
-        AMD of periodic_set up to k. 
+        An ndarray of shape (k,), the AMD of ``periodic_set`` up to `k`.
+        
+    Examples
+    --------
+    Make list of AMDs with ``k=100`` for crystals in mycif.cif::
+
+        amds = []
+        for periodic_set in amd.CifReader('mycif.cif'):
+            amds.append(amd.AMD(periodic_set, 100))
+            
+    Make list of AMDs with ``k=10`` for crystals in these CSD refcode families::
+    
+        amds = []
+        for periodic_set in amd.CSDReader(['HXACAN', 'ACSALA'], families=True):
+            amds.append(amd.AMD(periodic_set, 10))
+            
+    Manually pass a periodic set as a tuple (motif, cell)::
+
+        # simple cubic lattice
+        motif = np.array([[0,0,0]])
+        cell = np.array([[1,0,0], [0,1,0], [0,0,1]])
+        cubic_amd = amd.AMD((motif, cell), 100)
     """
     
     asymmetric_unit, multiplicities = None, None
@@ -41,36 +63,50 @@ def AMD(periodic_set, k):
     
     return np.average(pdd, axis=0, weights=multiplicities)
 
-
-def amd(*args, **kwargs):
-    warnings.warn("amd.amd() and amd.pdd() are deprecated; use amd.AMD() and amd.PDD() instead.", DeprecationWarning)
-    return AMD(*args, **kwargs)
-
-
-def PDD(periodic_set, k, order=True, collapse=True, collapse_tol=1e-4):
-    """
-    Computes a PDD up to k from a periodic set.
+def PDD(periodic_set: Union[PeriodicSet, Tuple[np.ndarray, np.ndarray]], k: int, 
+        order: bool = True, collapse: bool =True, collapse_tol: float = 1e-4) -> np.ndarray:
+    """Computes a PDD up to k from a periodic set.
     
     Parameters
     ----------
-    periodic_set : amd.PeriodicSet or tuple of ndarrays (motif, cell)
-        Representation of the periodic set, in Cartesian coordinates.
-        amd.CifReader yields PeriodicSets which can be given here. 
-        Otherwise pass a tuple of arrays (motif, cell) in Cartesian form. 
+    periodic_set : :class:`.periodicset.PeriodicSet` or tuple of ndarrays
+        A periodic set represented by a :class:`.periodicset.PeriodicSet` object or 
+        by a tuple (motif, cell) with coordinates in Cartesian form.
     k : int
-        A :math:`m_b` by k PDD matrix (with weights in the first column).
+        Number of columns in the PDD, plus one for the first column of weights.
     order : bool, optional
         Whether or not to lexicographically order the rows. Default True.
     collapse: bool, optional
         Whether or not to collapse identical rows (within a tolerance). Default True.
     collapse_tol: float
         If two rows have all entries closer than collapse_tol, they get collapsed.
-        Default 1e-4.
+        Default is 1e-4.
 
     Returns
     -------
     ndarray
-        PDD of periodic_set up to k. 
+        An ndarray with k+1 columns, the PDD of ``periodic_set`` up to `k`.
+        
+    Examples
+    --------
+    Make list of PDDs with ``k=100`` for crystals in mycif.cif::
+
+        pdds = []
+        for periodic_set in amd.CifReader('mycif.cif'):
+            pdds.append(amd.PDD(periodic_set, 100, order=False))    # do not lexicographically order rows
+            
+    Make list of PDDs with ``k=10`` for crystals in these CSD refcode families::
+    
+        pdds = []
+        for periodic_set in amd.CSDReader(['HXACAN', 'ACSALA'], families=True):
+            pdds.append(amd.PDD(periodic_set, 10, collapse=False))  # do not collapse rows
+            
+    Manually pass a periodic set as a tuple (motif, cell)::
+
+        # simple cubic lattice
+        motif = np.array([[0,0,0]])
+        cell = np.array([[1,0,0], [0,1,0], [0,0,1]])
+        cubic_amd = amd.PDD((motif, cell), 100)
     """
     
     asymmetric_unit, multiplicities = None, None
@@ -135,28 +171,47 @@ def PDD(periodic_set, k, order=True, collapse=True, collapse_tol=1e-4):
     
     return pdd
 
+def PDD_to_AMD(pdd: np.ndarray) -> np.ndarray:
+    """Calculates AMD from a PDD. Faster than computing both from scratch.
+    
+    Parameters
+    ----------
+    pdd : np.ndarray
+        The PDD of a periodic set. 
 
-def pdd(*args, **kwargs):
-    warnings.warn("amd.amd() and amd.pdd() are deprecated; use amd.AMD() and amd.PDD() instead.", DeprecationWarning)
-    return PDD(*args, **kwargs)
-
-def PDD_to_AMD(pdd):
-    """Calculates AMD from a PDD."""
+    Returns
+    -------
+    ndarray
+        The AMD of the periodic set.
+    """
     return np.average(pdd[:, 1:], weights=pdd[:, 0], axis=0)
 
-def PPC(periodic_set):
+def PPC(periodic_set: Union[PeriodicSet, Tuple[np.ndarray, np.ndarray]]) -> float:
+    r"""Calculate the point packing coefficient (PPC) of ``periodic_set``.
     
-    """
-    Calculate the point packing coefficient (ppc) of periodic_set.
-    The ppc is a constant of any periodic set determining the 
-    asymptotic behaviour of its AMD/PDD as k -> infinity. 
+    The PPC is a constant of any periodic set determining the 
+    asymptotic behaviour of its AMD or PDD as :math:`k \rightarrow \infty`. 
     
-    As k -> infinity, the ratio AMD_k / (n-th root of k) approaches
-    the ppc (as does any row of a PDD). 
+    As :math:`k \rightarrow \infty`, the ratio :math:`\text{AMD}_k / \sqrt[n]{k}`
+    approaches the PPC (as does any row of its PDD). 
     
-    For a unit cell U and m motif points in n dimensions,
-        ppc = nth_root(Vol[U] / (m * V_n))
-    where V_n is the volume of a unit sphere in n dimensions.
+    For a unit cell :math:`U` and :math:`m` motif points in :math:`n` dimensions,
+    
+    .. math::
+    
+        \text{PPC} = \sqrt[n]{\frac{\text{Vol}[U]}{m V_n}}
+        
+    where :math:`V_n` is the volume of a unit sphere in :math:`n` dimensions.
+    
+    Parameters
+    ----------
+    periodic_set : :class:`.periodicset.PeriodicSet` or tuple of 
+        ndarrays (motif, cell) representing the periodic set in Cartesian form.
+
+    Returns
+    -------
+    float
+        The PPC of ``periodic_set``.
     """
     
     if isinstance(periodic_set, PeriodicSet):
@@ -173,16 +228,17 @@ def PPC(periodic_set):
         V = (2 * np.math.factorial(t) * (4 * np.pi) ** t) / np.math.factorial(n)
     return (det / (m * V)) ** (1./n)
 
-def ppc(*args, **kwargs):
-    warnings.warn("amd.ppc() is deprecated; use amd.PPC() instead.", DeprecationWarning)
-    return PPC(*args, **kwargs)
-
-def AMD_estimate(periodic_set, k):
-    """
-    Calculates an estimate of AMD_k (or PDD) based on the 
-    point packing coefficient (ppc), which determines the
-    asymptotic behaviour. 
+def AMD_estimate(periodic_set: Union[PeriodicSet, Tuple[np.ndarray, np.ndarray]], k: int) -> np.ndarray:
+    r"""Calculates an estimate of AMD based on the PPC, using the fact that
+    
+    .. math::
+    
+        \lim_{k\rightarrow\infty}\frac{\text{AMD}_k}{\sqrt[n]{k}} = \sqrt[n]{\frac{\text{Vol}[U]}{m V_n}}
+    
+    where :math:`U` is the unit cell, :math:`m` is the number of motif points and
+    :math:`V_n` is the volume of a unit sphere in :math:`n`-dimensional space.
     """
+    
     if isinstance(periodic_set, PeriodicSet):
         motif, cell = periodic_set.motif, periodic_set.cell
     else:
@@ -192,10 +248,5 @@ def AMD_estimate(periodic_set, k):
     c = PPC(motif, cell)
     return np.array([(x ** (1. / n)) * c for x in range(1, k + 1)])
 
-def amd_estimate(*args, **kwargs):
-    warnings.warn("amd.amd_estimate() is deprecated; use amd.AMD_estimate() instead.", DeprecationWarning)
-    return AMD_estimate(*args, **kwargs)
-
-
 if __name__ == "__main__":
     pass
\ No newline at end of file
